@@ -12,7 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron.db import model_base
+from neutron_lib.db import model_base
 
 from neutron_dynamic_routing.db import bgp_db  # noqa
 from neutron_dynamic_routing.db import bgp_dragentscheduler_db  # noqa
