@@ -49,7 +49,7 @@ class BgpPlugin(service_base.ServicePluginBase,
                                    bgp_4byte_asn.ALIAS]
 
     def __init__(self):
-        super(BgpPlugin, self).__init__()
+        super().__init__()
         self.bgp_drscheduler = importutils.import_object(
             cfg.CONF.bgp_drscheduler_driver)
         self.agent_notifiers[bgp_consts.AGENT_TYPE_BGP_ROUTING] = (
@@ -97,6 +97,9 @@ class BgpPlugin(service_base.ServicePluginBase,
         registry.subscribe(self.router_gateway_callback,
                            resources.ROUTER_GATEWAY,
                            events.AFTER_DELETE)
+        registry.subscribe(self.router_callback,
+                           resources.ROUTER,
+                           events.AFTER_UPDATE)
         registry.subscribe(self.port_callback,
                            resources.PORT,
                            events.AFTER_UPDATE)
@@ -104,7 +107,7 @@ class BgpPlugin(service_base.ServicePluginBase,
     def get_bgp_speakers(self, context, filters=None, fields=None,
                          sorts=None, limit=None, marker=None,
                          page_reverse=False):
-        return super(BgpPlugin, self).get_bgp_speakers(
+        return super().get_bgp_speakers(
                                                     context,
                                                     filters=filters,
                                                     fields=fields,
@@ -114,13 +117,13 @@ class BgpPlugin(service_base.ServicePluginBase,
                                                     page_reverse=page_reverse)
 
     def get_bgp_speaker(self, context, bgp_speaker_id, fields=None):
-        return super(BgpPlugin, self).get_bgp_speaker(context,
-                                                      bgp_speaker_id,
-                                                      fields=fields)
+        return super().get_bgp_speaker(context,
+                                       bgp_speaker_id,
+                                       fields=fields)
 
     def create_bgp_speaker(self, context, bgp_speaker):
-        bgp_speaker = super(BgpPlugin, self).create_bgp_speaker(context,
-                                                                bgp_speaker)
+        bgp_speaker = super().create_bgp_speaker(context,
+                                                 bgp_speaker)
         registry.publish(dr_resources.BGP_SPEAKER, events.AFTER_CREATE,
                          self, payload=events.DBEventPayload(
                                    context,
@@ -129,15 +132,15 @@ class BgpPlugin(service_base.ServicePluginBase,
         return bgp_speaker
 
     def update_bgp_speaker(self, context, bgp_speaker_id, bgp_speaker):
-        return super(BgpPlugin, self).update_bgp_speaker(context,
-                                                         bgp_speaker_id,
-                                                         bgp_speaker)
+        return super().update_bgp_speaker(context,
+                                          bgp_speaker_id,
+                                          bgp_speaker)
 
     def delete_bgp_speaker(self, context, bgp_speaker_id):
         hosted_bgp_dragents = self.get_dragents_hosting_bgp_speakers(
                                                              context,
                                                              [bgp_speaker_id])
-        super(BgpPlugin, self).delete_bgp_speaker(context, bgp_speaker_id)
+        super().delete_bgp_speaker(context, bgp_speaker_id)
         for agent in hosted_bgp_dragents:
             self._bgp_rpc.bgp_speaker_removed(context,
                                               bgp_speaker_id,
@@ -145,32 +148,32 @@ class BgpPlugin(service_base.ServicePluginBase,
 
     def get_bgp_peers(self, context, fields=None, filters=None, sorts=None,
                       limit=None, marker=None, page_reverse=False):
-        return super(BgpPlugin, self).get_bgp_peers(
+        return super().get_bgp_peers(
                                                  context, fields=fields,
                                                  filters=filters, sorts=sorts,
                                                  limit=limit, marker=marker,
                                                  page_reverse=page_reverse)
 
     def get_bgp_peer(self, context, bgp_peer_id, fields=None):
-        return super(BgpPlugin, self).get_bgp_peer(context,
-                                                   bgp_peer_id,
-                                                   fields=fields)
+        return super().get_bgp_peer(context,
+                                    bgp_peer_id,
+                                    fields=fields)
 
     def create_bgp_peer(self, context, bgp_peer):
-        return super(BgpPlugin, self).create_bgp_peer(context, bgp_peer)
+        return super().create_bgp_peer(context, bgp_peer)
 
     def update_bgp_peer(self, context, bgp_peer_id, bgp_peer):
-        return super(BgpPlugin, self).update_bgp_peer(context,
-                                                      bgp_peer_id,
-                                                      bgp_peer)
+        return super().update_bgp_peer(context,
+                                       bgp_peer_id,
+                                       bgp_peer)
 
     def delete_bgp_peer(self, context, bgp_peer_id):
-        super(BgpPlugin, self).delete_bgp_peer(context, bgp_peer_id)
+        super().delete_bgp_peer(context, bgp_peer_id)
 
     def add_bgp_peer(self, context, bgp_speaker_id, bgp_peer_info):
-        ret_value = super(BgpPlugin, self).add_bgp_peer(context,
-                                                        bgp_speaker_id,
-                                                        bgp_peer_info)
+        ret_value = super().add_bgp_peer(context,
+                                         bgp_speaker_id,
+                                         bgp_peer_info)
         hosted_bgp_dragents = self.get_dragents_hosting_bgp_speakers(
                                                              context,
                                                              [bgp_speaker_id])
@@ -184,9 +187,9 @@ class BgpPlugin(service_base.ServicePluginBase,
         hosted_bgp_dragents = self.get_dragents_hosting_bgp_speakers(
             context, [bgp_speaker_id])
 
-        ret_value = super(BgpPlugin, self).remove_bgp_peer(context,
-                                                           bgp_speaker_id,
-                                                           bgp_peer_info)
+        ret_value = super().remove_bgp_peer(context,
+                                            bgp_speaker_id,
+                                            bgp_peer_info)
 
         for agent in hosted_bgp_dragents:
             self._bgp_rpc.bgp_peer_disassociated(context,
@@ -195,37 +198,37 @@ class BgpPlugin(service_base.ServicePluginBase,
                                                  agent.host)
 
     def add_bgp_speaker_to_dragent(self, context, agent_id, speaker_id):
-        super(BgpPlugin, self).add_bgp_speaker_to_dragent(context,
-                                                          agent_id,
-                                                          speaker_id)
+        super().add_bgp_speaker_to_dragent(context,
+                                           agent_id,
+                                           speaker_id)
 
     def remove_bgp_speaker_from_dragent(self, context, agent_id, speaker_id):
-        super(BgpPlugin, self).remove_bgp_speaker_from_dragent(context,
-                                                               agent_id,
-                                                               speaker_id)
+        super().remove_bgp_speaker_from_dragent(context,
+                                                agent_id,
+                                                speaker_id)
 
     def list_bgp_speaker_on_dragent(self, context, agent_id):
-        return super(BgpPlugin, self).list_bgp_speaker_on_dragent(context,
-                                                                  agent_id)
+        return super().list_bgp_speaker_on_dragent(context,
+                                                   agent_id)
 
     def list_dragent_hosting_bgp_speaker(self, context, speaker_id):
-        return super(BgpPlugin, self).list_dragent_hosting_bgp_speaker(
+        return super().list_dragent_hosting_bgp_speaker(
                                                                    context,
                                                                    speaker_id)
 
     def add_gateway_network(self, context, bgp_speaker_id, network_info):
-        return super(BgpPlugin, self).add_gateway_network(context,
-                                                          bgp_speaker_id,
-                                                          network_info)
+        return super().add_gateway_network(context,
+                                           bgp_speaker_id,
+                                           network_info)
 
     def remove_gateway_network(self, context, bgp_speaker_id, network_info):
-        return super(BgpPlugin, self).remove_gateway_network(context,
-                                                             bgp_speaker_id,
-                                                             network_info)
+        return super().remove_gateway_network(context,
+                                              bgp_speaker_id,
+                                              network_info)
 
     def get_advertised_routes(self, context, bgp_speaker_id):
-        return super(BgpPlugin, self).get_advertised_routes(context,
-                                                            bgp_speaker_id)
+        return super().get_advertised_routes(context,
+                                             bgp_speaker_id)
 
     def floatingip_update_callback(self, resource, event, trigger, payload):
         if event not in [events.AFTER_CREATE, events.AFTER_UPDATE]:
@@ -283,7 +286,7 @@ class BgpPlugin(service_base.ServicePluginBase,
             return
 
         ctx = context.get_admin_context()
-        with ctx.session.begin(subtransactions=True):
+        with ctx.session.begin():
             speakers = self._bgp_speakers_for_gateway_network(ctx,
                                                               gw_network)
             next_hops = self._next_hops_from_gateway_ips(
@@ -302,35 +305,24 @@ class BgpPlugin(service_base.ServicePluginBase,
                                                     rl)
 
     def router_gateway_callback(self, resource, event, trigger, payload=None):
-        if event == events.AFTER_CREATE:
-            self._handle_router_gateway_after_create(payload)
-        if event == events.AFTER_DELETE:
-            gw_network = payload.metadata.get('network_id')
-            router_id = payload.resource_id
-            next_hops = self._next_hops_from_gateway_ips(
-                payload.metadata.get('gateway_ips'))
-            ctx = context.get_admin_context()
-            speakers = self._bgp_speakers_for_gateway_network(ctx, gw_network)
-            for speaker in speakers:
-                if speaker.ip_version in next_hops:
-                    next_hop = next_hops[speaker.ip_version]
-                    prefixes = self._tenant_prefixes_by_router(ctx,
-                                                               router_id,
-                                                               speaker.id)
-                    routes = self._route_list_from_prefixes_and_next_hop(
-                                                                     prefixes,
-                                                                     next_hop)
-                self._handle_router_interface_after_delete(gw_network, routes)
-
-    def _handle_router_gateway_after_create(self, payload):
-        ctx = context.get_admin_context()
         gw_network = payload.metadata.get('network_id')
         router_id = payload.resource_id
-        with ctx.session.begin(subtransactions=True):
+        gateway_ips = payload.metadata.get('gateway_ips')
+        if event == events.AFTER_CREATE:
+            self._handle_router_gateway_after_create(gw_network, router_id,
+                                                     gateway_ips)
+        if event == events.AFTER_DELETE:
+            self._handle_router_gateway_after_delete(gw_network, router_id,
+                                                     gateway_ips)
+
+    def _handle_router_gateway_after_create(self, gw_network, router_id,
+                                            gateway_ips):
+        ctx = context.get_admin_context()
+        with ctx.session.begin():
             speakers = self._bgp_speakers_for_gateway_network(ctx,
                                                               gw_network)
             next_hops = self._next_hops_from_gateway_ips(
-                payload.metadata.get('gateway_ips'))
+                gateway_ips)
 
             for speaker in speakers:
                 if speaker.ip_version in next_hops:
@@ -344,6 +336,22 @@ class BgpPlugin(service_base.ServicePluginBase,
                     self.start_route_advertisements(ctx, self._bgp_rpc,
                                                     speaker.id, routes)
 
+    def _handle_router_gateway_after_delete(self, gw_network, router_id,
+                                            gateway_ips):
+        next_hops = self._next_hops_from_gateway_ips(gateway_ips)
+        ctx = context.get_admin_context()
+        speakers = self._bgp_speakers_for_gateway_network(ctx, gw_network)
+        for speaker in speakers:
+            if speaker.ip_version in next_hops:
+                next_hop = next_hops[speaker.ip_version]
+                prefixes = self._tenant_prefixes_by_router(ctx,
+                                                           router_id,
+                                                           speaker.id)
+                routes = self._route_list_from_prefixes_and_next_hop(
+                                                                    prefixes,
+                                                                    next_hop)
+            self._handle_router_interface_after_delete(gw_network, routes)
+
     def _handle_router_interface_after_delete(self, gw_network, routes):
         if gw_network and routes:
             ctx = context.get_admin_context()
@@ -352,6 +360,32 @@ class BgpPlugin(service_base.ServicePluginBase,
                 self.stop_route_advertisements(ctx, self._bgp_rpc,
                                                speaker.id, routes)
 
+    def router_callback(self, resource, event, trigger, payload):
+        if event != events.AFTER_UPDATE:
+            return
+
+        original_router = payload.states[0]
+        updated_router = payload.latest_state
+        external_gateway_info = updated_router.get("external_gateway_info")
+        if external_gateway_info is None:
+            return
+
+        gateway_ips = [
+            info["ip_address"] for info in
+            external_gateway_info["external_fixed_ips"]]
+
+        if "admin_state_up" in original_router and \
+                original_router.get("admin_state_up") != \
+                updated_router.get("admin_state_up"):
+            router_id = updated_router["id"]
+            gw_network = external_gateway_info["network_id"]
+            if updated_router.get("admin_state_up"):
+                self._handle_router_gateway_after_create(gw_network, router_id,
+                                                         gateway_ips)
+            else:
+                self._handle_router_gateway_after_delete(gw_network, router_id,
+                                                         gateway_ips)
+
     def port_callback(self, resource, event, trigger, payload):
         if event != events.AFTER_UPDATE:
             return
@@ -368,7 +402,7 @@ class BgpPlugin(service_base.ServicePluginBase,
         # if host in the port binding has changed, update next-hops
         if original_host != updated_host and bool('compute:' in device_owner):
             ctx = context.get_admin_context()
-            with ctx.session.begin(subtransactions=True):
+            with ctx.session.begin():
                 ext_nets = self.get_external_networks_for_port(ctx,
                                                                updated_port)
                 for ext_net in ext_nets:
