@@ -15,16 +15,16 @@
 
 import copy
 import sys
-import uuid
+from unittest import mock
 
 import eventlet
-import mock
+from neutron_lib import context
 from oslo_config import cfg
+from oslo_utils import uuidutils
 import testtools
 
-from neutron.agent.common import config
 from neutron.common import config as n_config
-from neutron import context
+from neutron.conf.agent import common as config
 from neutron.tests import base
 
 from neutron_dynamic_routing.services.bgp.agent import bgp_dragent
@@ -32,10 +32,10 @@ from neutron_dynamic_routing.services.bgp.agent import config as bgp_config
 
 HOSTNAME = 'hostname'
 rpc_api = bgp_dragent.BgpDrPluginApi
-BGP_PLUGIN = '%s.%s' % (rpc_api.__module__, rpc_api.__name__)
+BGP_PLUGIN = '{}.{}'.format(rpc_api.__module__, rpc_api.__name__)
 
-FAKE_BGPSPEAKER_UUID = str(uuid.uuid4())
-FAKE_BGPPEER_UUID = str(uuid.uuid4())
+FAKE_BGPSPEAKER_UUID = uuidutils.generate_uuid()
+FAKE_BGPPEER_UUID = uuidutils.generate_uuid()
 
 FAKE_BGP_SPEAKER = {'id': FAKE_BGPSPEAKER_UUID,
                     'local_as': 12345,
@@ -63,9 +63,10 @@ FAKE_ROUTES = {'routes': {'id': FAKE_BGPSPEAKER_UUID,
 
 class TestBgpDrAgent(base.BaseTestCase):
     def setUp(self):
-        super(TestBgpDrAgent, self).setUp()
+        super().setUp()
         cfg.CONF.register_opts(bgp_config.BGP_DRIVER_OPTS, 'BGP')
         cfg.CONF.register_opts(bgp_config.BGP_PROTO_CONFIG_OPTS, 'BGP')
+        cfg.CONF.register_opts(config.AGENT_STATE_OPTS, 'AGENT')
         mock_log_p = mock.patch.object(bgp_dragent, 'LOG')
         self.mock_log = mock_log_p.start()
         self.driver_cls_p = mock.patch(
@@ -74,17 +75,20 @@ class TestBgpDrAgent(base.BaseTestCase):
         self.driver_cls = self.driver_cls_p.start()
         self.context = context.get_admin_context()
 
-    def test_bgp_dragent_manager(self):
+    @mock.patch('neutron.common.config.init')
+    def test_bgp_dragent_manager(self, mock_init):
+        mock_init.return_value = '/tmp/test'
         state_rpc_str = 'neutron.agent.rpc.PluginReportStateAPI'
         # sync_state is needed for this test
         with mock.patch.object(bgp_dragent.BgpDrAgentWithStateReport,
                                'sync_state',
                                autospec=True) as mock_sync_state:
             with mock.patch(state_rpc_str) as state_rpc:
-                with mock.patch.object(sys, 'argv') as sys_argv:
-                    sys_argv.return_value = [
-                        'bgp_dragent', '--config-file',
-                        base.etcdir('neutron.conf')]
+                test_args = [
+                    'bgp_dragent', '--config-file',
+                    base.etcdir('neutron.conf')
+                ]
+                with mock.patch.object(sys, 'argv', test_args):
                     config.register_agent_state_opts_helper(cfg.CONF)
                     n_config.init(sys.argv[1:])
                     agent_mgr = bgp_dragent.BgpDrAgentWithStateReport(
@@ -109,6 +113,14 @@ class TestBgpDrAgent(base.BaseTestCase):
             bgp_dr.after_start()
             self.assertIsNotNone(len(sync_state.mock_calls))
 
+    def test_agent_updated(self):
+        bgp_dr = bgp_dragent.BgpDrAgentWithStateReport(HOSTNAME)
+        payload = {'admin_state_up': True}
+        with mock.patch.object(bgp_dr, 'agent_updated') as agent_updated:
+            bgp_dr.agent_updated(self.context, payload)
+            self.assertIsNotNone(len(agent_updated.mock_calls))
+            self.assertEqual(1, bgp_dr.agent_updated.call_count)
+
     def _test_sync_state_helper(self, bgp_speaker_list=None,
                                 cached_info=None,
                                 safe_configure_call_count=0,
@@ -119,11 +131,11 @@ class TestBgpDrAgent(base.BaseTestCase):
                                 synced_bgp_speakers=None):
         bgp_dr = bgp_dragent.BgpDrAgent(HOSTNAME)
 
-        attrs_to_mock = dict(
-            [(a, mock.MagicMock())
-             for a in ['plugin_rpc', 'sync_bgp_speaker',
-                       'safe_configure_dragent_for_bgp_speaker',
-                       'remove_bgp_speaker_from_dragent']])
+        attrs_to_mock = {
+            a: mock.Mock()
+            for a in ['plugin_rpc', 'sync_bgp_speaker',
+                      'safe_configure_dragent_for_bgp_speaker',
+                      'remove_bgp_speaker_from_dragent']}
 
         with mock.patch.multiple(bgp_dr, **attrs_to_mock):
             if not cached_info:
@@ -278,12 +290,12 @@ class TestBgpDrAgent(base.BaseTestCase):
 
         bgp_dr = bgp_dragent.BgpDrAgent(HOSTNAME)
 
-        attrs_to_mock = dict(
-            [(a, mock.MagicMock())
-             for a in ['remove_bgp_peer_from_bgp_speaker',
-                       'add_bgp_peers_to_bgp_speaker',
-                       'advertise_routes_via_bgp_speaker',
-                       'withdraw_route_via_bgp_speaker']])
+        attrs_to_mock = {
+            a: mock.Mock()
+            for a in ['remove_bgp_peer_from_bgp_speaker',
+                      'add_bgp_peers_to_bgp_speaker',
+                      'advertise_routes_via_bgp_speaker',
+                      'withdraw_route_via_bgp_speaker']}
 
         with mock.patch.multiple(bgp_dr, **attrs_to_mock):
             bgp_dr.cache.cache = cached_info
@@ -400,11 +412,11 @@ class TestBgpDrAgent(base.BaseTestCase):
             with mock.patch.object(bgp_dragent.LOG, 'error') as log:
                 bgp_dr = bgp_dragent.BgpDrAgent(HOSTNAME)
                 with mock.patch.object(bgp_dr,
-                        'schedule_full_resync') as schedule_full_resync:
+                                       'schedule_full_resync') as mock_resync:
                     bgp_dr.sync_state(mock.ANY)
 
                     self.assertTrue(log.called)
-                    self.assertTrue(schedule_full_resync.called)
+                    self.assertTrue(mock_resync.called)
 
     def test_periodic_resync(self):
         bgp_dr = bgp_dragent.BgpDrAgent(HOSTNAME)
@@ -499,7 +511,7 @@ class TestBgpDrAgentEventHandler(base.BaseTestCase):
                 'agent.bgp_dragent.BgpSpeakerCache'
 
     def setUp(self):
-        super(TestBgpDrAgentEventHandler, self).setUp()
+        super().setUp()
         cfg.CONF.register_opts(bgp_config.BGP_DRIVER_OPTS, 'BGP')
         cfg.CONF.register_opts(bgp_config.BGP_PROTO_CONFIG_OPTS, 'BGP')
 
@@ -561,7 +573,7 @@ class TestBgpDrAgentEventHandler(base.BaseTestCase):
     def test_add_bgp_speaker_helper(self):
         self.plugin.get_bgp_speaker_info.return_value = FAKE_BGP_SPEAKER
         add_bs_p = mock.patch.object(self.bgp_dr,
-                                   'add_bgp_speaker_on_dragent')
+                                     'add_bgp_speaker_on_dragent')
         add_bs = add_bs_p.start()
         self.bgp_dr.add_bgp_speaker_helper(FAKE_BGP_SPEAKER['id'])
         self.plugin.assert_has_calls([
@@ -623,7 +635,7 @@ class TestBgpDrAgentEventHandler(base.BaseTestCase):
 class TestBGPSpeakerCache(base.BaseTestCase):
 
     def setUp(self):
-        super(TestBGPSpeakerCache, self).setUp()
+        super().setUp()
         self.expected_cache = {FAKE_BGP_SPEAKER['id']:
                                {'bgp_speaker': FAKE_BGP_SPEAKER,
                                 'peers': {},
@@ -725,3 +737,20 @@ class TestBGPSpeakerCache(base.BaseTestCase):
         self.assertFalse(self.bs_cache.is_route_advertised(
             FAKE_BGP_SPEAKER['id'], {'destination': 'foo-destination',
                                      'next_hop': 'foo-next-hop'}))
+
+    def test_put_bgp_speaker_adv_route_and_remove_with_next_hop_none(self):
+        self.bs_cache.put_bgp_speaker(FAKE_BGP_SPEAKER)
+        self.bs_cache.put_adv_route(FAKE_BGP_SPEAKER['id'], FAKE_ROUTE)
+        expected_cache = copy.deepcopy(self.expected_cache)
+        expected_cache[FAKE_BGP_SPEAKER['id']]['advertised_routes'].append(
+            FAKE_ROUTE)
+        self.assertEqual(expected_cache, self.bs_cache.cache)
+
+        fake_route_2 = copy.deepcopy(FAKE_ROUTE)
+        fake_route_2.update({'next_hop': None})
+        self.assertTrue(self.bs_cache.is_route_advertised(
+            FAKE_BGP_SPEAKER['id'], fake_route_2))
+
+        self.bs_cache.remove_adv_route(FAKE_BGP_SPEAKER['id'],
+                                       fake_route_2)
+        self.assertEqual(self.expected_cache, self.bs_cache.cache)
